@@ -2,7 +2,7 @@
 #     Project: PyOdoo
 # Description: API for Odoo
 #      Author: Fabio Castelli (Muflone) <muflone@muflone.com>
-#   Copyright: 2021 Fabio Castelli
+#   Copyright: 2021-2022 Fabio Castelli
 #     License: GPL-3+
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -19,10 +19,13 @@
 ##
 
 APP_NAME = 'PyOdoo'
-APP_VERSION = '0.2.1'
+APP_VERSION = '0.5.0'
 APP_DESCRIPTION = 'API for Odoo'
-APP_ID = 'pyodoo.muflone.com'
-APP_URL = 'http://www.muflone.com/pyodoo/'
+APP_DOMAIN = 'pyodoo'
+APP_ID = f'{APP_DOMAIN}.muflone.com'
 APP_AUTHOR = 'Fabio Castelli'
 APP_AUTHOR_EMAIL = 'muflone@muflone.com'
-APP_COPYRIGHT = 'Copyright 2021 %s' % APP_AUTHOR
+APP_COPYRIGHT = f'Copyright 2021-2022 {APP_AUTHOR}'
+URL_AUTHOR = 'https://www.muflone.com/'
+URL_APPLICATION = f'{URL_AUTHOR}{APP_DOMAIN}/'
+URL_SOURCES = f'https://github.com/muflone/{APP_DOMAIN}/'
